Instructed Glacier Model (IGM)
==============================

Since v1.6.2, OGGM comes with a new interface able to call the
`Instructed Glacier Model (IGM) <https://github.com/jouvetg/igm>`_
while keeping your familiar OGGM workflow. This is still very
much experimental and under development, but we are excited to
see where this will lead us!

See `this tutorial <https://tutorials.oggm.org/master/notebooks/tutorials/ioggm.html>`_ for a sneak peak!
